.. currentmodule:: disnake_compass

Component Factory Implementation
================================

.. automodule:: disnake_compass.impl.factory

Classes
-------

.. attributetable:: disnake_compass.impl.factory.ComponentFactory

.. autoclass:: disnake_compass.impl.factory.ComponentFactory
    :members:

.. attributetable:: disnake_compass.impl.factory.NoopFactory

.. autoclass:: disnake_compass.impl.factory.NoopFactory
    :members:
